@@ -54,12 +54,18 @@ def migrate(ctx_obj):
 
 
 @click.group()
+@click.option('--verbose', is_flag=True)
 @click.pass_context
-def main(ctx):
+def main(ctx, verbose):
     if not os.path.exists(os.path.join(BASE_DIR, 'manage.py')):
         raise click.UsageError('make sure you are in the same directory as manage.py')
+
+    if verbose:
+        os.environ['ALDRYN_ADDONS_DEBUG'] = 'True'
+
     from . import startup
     startup._setup(BASE_DIR)
+
     ctx.obj = {
         'settings': {key: getattr(django_settings, key) for key in dir(django_settings)}
     }
@@ -70,10 +76,28 @@ main.add_command(worker)
 main.add_command(migrate)
 
 
+def get_env():
+    # setup default uwsgi environment variables
+    env = {
+        'UWSGI_ENABLE_THREADS': '1',
+    }
+    if boolean_ish(os.environ.get('ENABLE_UWSGI_CHEAPER', 'on')):
+        env.update({
+            'UWSGI_CHEAPER': '1',
+            'UWSGI_CHEAPER_ALGO': 'busyness',
+            'UWSGI_CHEAPER_INITIAL': '1',
+            'UWSGI_CHEAPER_BUSINESS_VERBOSE': '1',
+            'UWSGI_CHEAPER_BUSINESS_BACKLOG_ALERT': '10',
+            'UWSGI_CHEAPER_OVERLOAD': '30',
+        })
+    env.update(os.environ)
+    return env
+
+
 def execute(args, script=None):
     # TODO: is cleanup needed before calling exec? (open files, ...)
     command = script or args[0]
-    os.execvp(command, args)
+    os.execvpe(command, args, get_env())
 
 
 def start_uwsgi_command(settings, port=None):
@@ -81,6 +105,7 @@ def start_uwsgi_command(settings, port=None):
         'uwsgi',
         '--module=wsgi',
         '--http=0.0.0.0:{}'.format(port or settings.get('PORT')),
+        '--master',
         '--workers={}'.format(settings['DJANGO_WEB_WORKERS']),
         '--max-requests={}'.format(settings['DJANGO_WEB_MAX_REQUESTS']),
         '--harakiri={}'.format(settings['DJANGO_WEB_TIMEOUT']),
